[PATCH 11/11] dm: core: Drop unused parameter from dm_extended_scan_fdt()

Simon Glass sjg at chromium.org
Sun Nov 29 01:50:10 CET 2020


This doesn't need to be passed the devicetree anymore. Drop it.
Also rename the function to drop the _fdt suffix.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 drivers/core/root.c | 6 +++---
 include/dm/root.h   | 5 ++---
 test/dm/test-fdt.c  | 2 +-
 test/dm/test-main.c | 2 +-
 4 files changed, 7 insertions(+), 8 deletions(-)

diff --git a/drivers/core/root.c b/drivers/core/root.c
index 54498b2df71..6f8168bb92d 100644
--- a/drivers/core/root.c
+++ b/drivers/core/root.c
@@ -262,7 +262,7 @@ static int dm_scan_fdt_ofnode_path(const char *path, bool pre_reloc_only)
 	return dm_scan_fdt_node(gd->dm_root, node, pre_reloc_only);
 }
 
-int dm_extended_scan_fdt(const void *blob, bool pre_reloc_only)
+int dm_extended_scan(bool pre_reloc_only)
 {
 	int ret, i;
 	const char * const nodes[] = {
@@ -315,9 +315,9 @@ int dm_init_and_scan(bool pre_reloc_only)
 	}
 
 	if (CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)) {
-		ret = dm_extended_scan_fdt(gd->fdt_blob, pre_reloc_only);
+		ret = dm_extended_scan(pre_reloc_only);
 		if (ret) {
-			debug("dm_extended_scan_dt() failed: %d\n", ret);
+			debug("dm_extended_scan() failed: %d\n", ret);
 			return ret;
 		}
 	}
diff --git a/test/dm/test-fdt.c b/test/dm/test-fdt.c
index 9507636b630..673ffb4de94 100644
--- a/test/dm/test-fdt.c
+++ b/test/dm/test-fdt.c
@@ -257,7 +257,7 @@ static int dm_test_fdt(struct unit_test_state *uts)
 	int ret;
 	int i;
 
-	ret = dm_extended_scan_fdt(gd->fdt_blob, false);
+	ret = dm_extended_scan(false);
 	ut_assert(!ret);
 
 	ret = uclass_get(UCLASS_TEST_FDT, &uc);
diff --git a/test/dm/test-main.c b/test/dm/test-main.c
index 2ab73b647e6..4814e186cb7 100644
--- a/test/dm/test-main.c
+++ b/test/dm/test-main.c
@@ -94,7 +94,7 @@ static int dm_do_test(struct unit_test_state *uts, struct unit_test *test,
 		ut_assertok(do_autoprobe(uts));
 	if (!CONFIG_IS_ENABLED(OF_PLATDATA) &&
 	    (test->flags & UT_TESTF_SCAN_FDT))
-		ut_assertok(dm_extended_scan_fdt(gd->fdt_blob, false));
+		ut_assertok(dm_extended_scan(false));
 
 	/*
 	 * Silence the console and rely on console recording to get
diff --git a/include/dm/root.h b/include/dm/root.h
index e277ebb9523..830e31312df 100644
--- a/include/dm/root.h
+++ b/include/dm/root.h
@@ -54,18 +54,17 @@ int dm_scan_platdata(bool pre_reloc_only);
 int dm_scan_fdt(bool pre_reloc_only);
 
 /**
  * dm_extended_scan_fdt() - Scan the device tree and bind drivers
  *
  * This calls dm_scna_dft() which scans the device tree and creates a driver
  * for each node. the top-level subnodes are examined and also all sub-nodes
  * of "clocks" node.
  *
- * @blob: Pointer to device tree blob
  * @pre_reloc_only: If true, bind only nodes with special devicetree properties,
  * or drivers with the DM_FLAG_PRE_RELOC flag. If false bind all drivers.
  * @return 0 if OK, -ve on error
  */
-int dm_extended_scan_fdt(const void *blob, bool pre_reloc_only);
+int dm_extended_scan(bool pre_reloc_only);
 
 /**
  * dm_scan_other() - Scan for other devices
@@ -54,18 +54,17 @@ int dm_scan_platdata(bool pre_reloc_only);
 
 /**
- * dm_extended_scan_fdt() - Scan the device tree and bind drivers
+ * dm_extended_scan() - Scan the device tree and bind drivers
  *
  * This calls dm_scna_dft() which scans the device tree and creates a driver
-- 
2.29.2.454.gaff20da3a2-goog



More information about the U-Boot mailing list